alicloud

package module
v0.16.2-dev Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 23, 2018 License: Apache-2.0 Imports: 5 Imported by: 0

README

Build Status

AliCloud Resource Provider

The AliCloud resource provider for Pulumi lets you use AliCloud resources in your cloud programs. To use this package, please install the Pulumi CLI first.

Installing

This package is available in many languages in the standard packaging formats.

Node.js (Java/TypeScript)

To use from JavaScript or TypeScript in Node.js, install using either npm:

$ npm install @pulumi/alicloud

or yarn:

$ yarn add @pulumi/alicloud
Python

To use from Python, install using pip:

$ pip install pulumi_alicloud
Go

To use from Go, use go get to grab the latest version of the library

$ go get github.com/pulumi/pulumi-alicloud/sdk/go/...

Concepts

The @pulumi/alicloud package provides a strongly-typed means to build cloud applications that create and interact closely with AliCloud resources. Resources are exposed for the entire AliCloud surface area.

Reference

For detailed reference documentation, please visit the API docs.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Provider

func Provider() tfbridge.ProviderInfo

Provider returns additional overlaid schema and metadata associated with the alicloud package.

Types

This section is empty.

Jump to